@@ -21,17 +21,16 @@
 
 #if ZORPLIB_ENABLE_CAPS
 
-const gchar *zorp_caps = "cap_net_admin,cap_net_bind_service=p";
+const gchar *zorp_caps = NULL;
 
 /**
- * cap_modify:
- * @capability: capability to turn off or on
- * @onoff: specifies whether the capability should be enabled or disabled
- *
  * This function modifies the current permitted set of capabilities by
- * enabling or disabling the capability specified in @capability.
+ * enabling or disabling the capability specified in capability.
  *
- * Returns: whether the operation was successful.
+ * @param[in] capability capability to turn off or on
+ * @param[in] onoff specifies whether the capability should be enabled or disabled
+ *
+ * @returns whether the operation was successful.
  **/
 gboolean 
 cap_modify(int capability, int onoff)
@@ -40,68 +39,51 @@ cap_modify(int capability, int onoff)
 
   z_enter();
   if (!zorp_caps)
-    {
-      z_leave();
-      return TRUE;
-    }
+    z_return(TRUE);
   
   caps = cap_get_proc();
   if (!caps)
-    {
-      z_leave();
-      return FALSE;
-    }
-
+    z_return(FALSE);
 
   if (cap_set_flag(caps, CAP_EFFECTIVE, 1, &capability, onoff) == -1)
     {
       cap_free(caps);
-      z_leave();
-      return FALSE;
+      z_return(FALSE);
     }
 
   if (cap_set_proc(caps) == -1)
     {
       cap_free(caps);
-      z_leave();
-      return FALSE;
+      z_return(FALSE);
     }
   cap_free(caps);
-  z_leave();
-  return TRUE;
+  z_return(TRUE);
 }
 
 /**
- * cap_save:
+ * Save the set of current capabilities and return it.
  *
- * Save the set of current capabilities and return it. The caller might
- * restore the saved set of capabilities by using cap_restore().
+ * @returns the current set of capabilities
  *
- * Returns: the current set of capabilities
+ * This function saves the set of current capabilities and returns it.
+ * The caller might restore the saved set of capabilities by using cap_restore().
  **/
 cap_t 
 cap_save(void)
 {
-  cap_t res;
-  
   z_enter();
   if (!zorp_caps)
-    {
-      z_leave();
-      return NULL;
-    }
-  res = cap_get_proc();
-  z_leave();
-  return res;
+    z_return(NULL);
+
+  z_return(cap_get_proc());
 }
 
 /**
- * cap_restore:
- * @r: capability set saved by cap_save()
+ * Restore the set of current capabilities specified by r.
  *
- * Restore the set of current capabilities specified by @r.
+ * @param[in] r capability set saved by cap_save()
  *
- * Returns: whether the operation was successful.
+ * @returns whether the operation was successful.
  **/
 gboolean
 cap_restore(cap_t r)
@@ -110,14 +92,11 @@ cap_restore(cap_t r)
 
   z_enter();
   if (!zorp_caps)
-    {
-      z_leave();
-      return TRUE;
-    }
+    z_return(TRUE);
+
   rc = cap_set_proc(r) != -1;
   cap_free(r);
-  z_leave();
-  return rc;
+  z_return(rc);
 }
 
 #endif
