@@ -18,7 +18,13 @@
 #include <zorp/error.h>
 
 #ifdef G_OS_WIN32
-/* it's not complete... only contains error codes used somewhere */
+/**
+ * Translate Unix error code to Windows error code.
+ *
+ * @param[in] e Unix error code
+ *
+ * It's not complete... only contains error codes used somewhere.
+ **/
 static int
 z_errno_translate(int e)
 {
@@ -27,6 +33,8 @@ z_errno_translate(int e)
       case EAGAIN: /* a.k.a. EWOULDBLOCK */
       case EINPROGRESS:
         return WSAEWOULDBLOCK;
+      case ENOTSOCK:
+        return WSAENOTSOCK;
       case EINTR:
         /* WSAEINTR does exist, but has a different meaning */
         return 0;
@@ -36,18 +44,31 @@ z_errno_translate(int e)
 }
 #endif
 
+/**
+ * Check if errno/WSAGetLastError() is equal to e, compensating for platform differences.
+ *
+ * @param[in] e Unix error code
+ *
+ * @returns TRUE if the compared error values are equivalent.
+ **/
 gboolean
 z_errno_is(int e)
 {
 #ifdef G_OS_WIN32
   int err;
+  
   err = WSAGetLastError();
-  if ( err == z_errno_translate(e))
+  if (err == z_errno_translate(e))
     return TRUE;
 #endif
   return (errno == e);
 }
 
+/**
+ * Get the error value, using WSAGetLastError() on Windows and errno elsewhere.
+ *
+ * @returns the error value
+ **/
 int
 z_errno_get(void)
 {
@@ -58,6 +79,11 @@ z_errno_get(void)
 #endif
 }
 
+/**
+ * Set the error value, using WSASetLastError() on Windows and errno elsewhere.
+ *
+ * @param[in] e the error value
+ **/
 void
 z_errno_set(int e)
 {
