@@ -231,6 +231,9 @@ z_stream_fd_watch_dispatch(ZStream *s, GSource *src)
       else if (mystream->super.want_write)
         rc = (*mystream->super.write_cb)(&mystream->super, poll_cond, mystream->super.user_data_write);
 
+      else if (mystream->super.want_pri)
+        rc = (*mystream->super.pri_cb)(&mystream->super, poll_cond, mystream->super.user_data_pri);
+
       else if (!mystream->shutdown)
         {
           /* basically an EOF */
