@@ -12,6 +12,9 @@
 #include <zorp/zobject.h>
 #include <zorp/log.h>
 
+/**
+ * struct type to hold ZObject virtual methods.
+ **/
 typedef struct _ZClassFuncs
 { 
   gint method_count;
@@ -19,11 +22,11 @@ typedef struct _ZClassFuncs
 } ZClassFuncs;
 
 /**
- * z_object_free_method:
- * @s: ZObject instance
- * 
- * This function is the free method of the ZObject class. It currently does
- * nothing as ZObject has no real data structure.
+ * This function is the free method of the ZObject class.
+ *
+ * @param  s ZObject instance
+ *
+ * This function currently does nothing as ZObject has no real data structure.
  **/
 void
 z_object_free_method(ZObject *s G_GNUC_UNUSED)
@@ -31,7 +34,12 @@ z_object_free_method(ZObject *s G_GNUC_UNUSED)
   /* empty */
 }
 
-/* dummy ZClass class descriptor */
+/**
+ * Dummy ZClass class descriptor.
+ **/
+#ifdef G_OS_WIN32
+  LIBZORPLL_EXTERN
+#endif
 ZClass ZClass__class =
 {
   Z_CLASS_HEADER,
@@ -41,13 +49,21 @@ ZClass ZClass__class =
   NULL
 };
 
+/**
+ * ZObject virtual methods.
+ **/
 static ZObjectFuncs z_object_funcs = 
 {
   Z_FUNCS_COUNT(ZObject),
   z_object_free_method
 };
 
-/* root class */
+/**
+ * Descriptor of ZObject, the base (or root) class.
+ **/
+#ifdef G_OS_WIN32
+  LIBZORPLL_EXTERN
+#endif
 ZClass ZObject__class =
 {
   Z_CLASS_HEADER,
@@ -58,53 +74,10 @@ ZClass ZObject__class =
 };
 
 /**
- * z_object_ref:
- * @self: ZObject instance
+ * This function checks whether subclass is derived from class.
  *
- * Increment the reference count of @self.
- **/
-ZObject *
-z_object_ref(ZObject *self)
-{
-  if (self)
-    {
-      g_static_mutex_lock(&self->ref_lock);
-      z_incref(&self->ref_cnt);
-      g_static_mutex_unlock(&self->ref_lock);
-    }
-  return self;
-}
-
-/**
- * z_object_unref:
- * @self: ZObject instance
- *
- * Decrement the reference count of @self and free it if the reference count
- * goes down to zero.
- **/
-void
-z_object_unref(ZObject *self)
-{
-  if (self)
-    {
-      g_static_mutex_lock(&self->ref_lock);
-      if (z_decref(&self->ref_cnt) == 0)
-        {
-          g_static_mutex_unlock(&self->ref_lock);
-          z_object_free(self);
-          g_free(self);
-          return;
-        }
-      g_static_mutex_unlock(&self->ref_lock);
-    }
-}
-
-/**
- * z_object_is_subclass:
- * @class: parent class
- * @subclass: child class
- *
- * This function checks whether @subclass is derived from @class.
+ * @param[in] class parent class
+ * @param[in] subclass child class
  **/
 gboolean
 z_object_is_subclass(ZClass *class, ZClass *subclass)
@@ -118,12 +91,11 @@ z_object_is_subclass(ZClass *class, ZClass *subclass)
 }
 
 /**
- * z_object_is_compatible:
- * @self: ZObject instance
- * @class: class descriptor
+ * This function checks whether self is compatible of class, e.g.\ whether
+ * it is derived from class.
  *
- * This function checks whether @self is compatible of @class, e.g. whether
- * it is derived from @class.
+ * @param[in] self ZObject instance
+ * @param[in] class class descriptor
  **/
 gboolean
 z_object_is_compatible(ZObject *self, ZClass *class)
@@ -135,11 +107,10 @@ z_object_is_compatible(ZObject *self, ZClass *class)
 }
 
 /**
- * z_object_is_instance:
- * @self: ZObject instance
- * @class: class descriptor
+ * This function returns whether self is an instance of class.
  *
- * This function returns whether @self is an instance of @class.
+ * @param[in] self ZObject instance
+ * @param[in] class class descriptor
  **/
 gboolean
 z_object_is_instance(ZObject *self, ZClass *class)
@@ -151,8 +122,9 @@ z_object_is_instance(ZObject *self, ZClass *class)
 }
 
 /**
- * z_object_resolve_funcs:
- * @class: class descriptor
+ * Resolve NULL methods to be used from parent classes.
+ *
+ * @param[in] class class descriptor
  *
  * This function is called once for each class instantiated. It resolves
  * NULL methods to be used from parent classes.
@@ -178,34 +150,39 @@ z_object_resolve_funcs(ZClass *class)
 }
 
 /**
- * z_object_new:
- * @class: class descriptor
+ * Creates a new instance of class.
  *
- * This function takes a class descriptor and creates an instance of @class
+ * @param[in] class class descriptor
+ *
+ * This function takes a class descriptor and creates an instance of class
  * by allocating an appropriate memory block, initializing the reference
  * counter and ZObject specific fields.
+ *
+ * @returns the new object
  **/
 ZObject *
 z_object_new(ZClass *class)
 {
   ZObject *inst;
   
+  if (class->super.isa == NULL)
+    class->super.isa = &ZClass__class;
+  
   if (!class->funcs_resolved)
     z_object_resolve_funcs(class);
   
   inst = g_malloc0(class->size);
   inst->isa = class;
-  inst->ref_cnt = 1;
+  z_refcount_set(&inst->ref_cnt, 1);
   return inst;
 }
 
 /**
- * z_object_new_compatible:
- * @class: class decriptor
- * @compat: class descriptor
+ * This function checks whether class is compatible with compat, and if it
+ * is, it returns a new instance of class.
  *
- * This function checks whether @class is compatible with @compat, and if it
- * is, it returns a new instance of @class.
+ * @param[in] class class decriptor
+ * @param[in] compat class descriptor
  **/
 ZObject *
 z_object_new_compatible(ZClass *class, ZClass *compat)
