@@ -8,6 +8,10 @@
 
 #include <glib.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 typedef struct _ZHeader
 {
   GString *key;
@@ -21,7 +25,7 @@ typedef struct _ZHeaderSet
 } ZHeaderSet;
 
 GList *z_header_set_get_all_headers(ZHeaderSet *self);
-ZHeader *z_header_set_iterate(ZHeaderSet *self, gchar *key, gpointer *opaque);
+ZHeader *z_header_set_iterate(ZHeaderSet *self, const gchar *key, gpointer *opaque);
 gboolean z_header_set_add(ZHeaderSet *self, GString *key, GString *value, gboolean multiple);
 void z_header_set_init(ZHeaderSet *self);
 void z_header_set_destroy(ZHeaderSet *self);
@@ -38,4 +42,8 @@ z_header_set_get_count(ZHeaderSet *self)
   return self->headers_count;
 }
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
