@@ -19,11 +19,9 @@
 extern "C" {
 #endif
 
-/*+
-
-  ZPoll interface encapsulates a poll() loop.
-
-  +*/
+/**
+ * ZPoll interface encapsulates a poll() loop.
+ **/
 typedef struct _ZPoll ZPoll;
 
 ZPoll *z_poll_new(void);
