@@ -19,10 +19,25 @@
 extern "C" {
 #endif
 
+/** bind to the next unused port in the same group */
 #define ZSF_LOOSE_BIND    0x0001
 #define ZSF_ACCEPT_ONE    0x0002
 #define ZSF_MARK_TPROXY   0x0004
+#define ZSF_TRANSPARENT   0x0008
+/** bind to a port in the same group chosen at (truly) random */
+#define ZSF_RANDOM_BIND   0x0010
 
+static inline const gchar *
+z_socket_type_to_str(gint socket_type)
+{
+  return socket_type == SOCK_STREAM ? "stream" : 
+         socket_type == SOCK_DGRAM  ? "dgram" : 
+         "unknown";
+}
+
+/**
+ * Type for table of socket-related functions.
+ **/
 typedef struct _ZSocketFuncs
 {
   gint (*bind)(int fd, struct sockaddr *sa, socklen_t salen, guint32 sock_flags);
