@@ -24,7 +24,9 @@ GSource *z_threshold_source_new(guint idle_threshold, guint busy_threshold);
 void z_threshold_source_set_threshold(GSource *source, guint idle_threshold, guint busy_threshold);
 
 void z_timeout_source_set_timeout(GSource *s, gulong new_timeout);
+void z_timeout_source_set_time(GSource *source, GTimeVal *nexttime);
 GSource *z_timeout_source_new(gulong initial_timeout);
+void z_timeout_source_disable(GSource *source);
 
 #ifdef __cplusplus
 }
