@@ -19,7 +19,7 @@
 extern "C" {
 #endif
 
-ZStream *z_stream_fd_new(gint fd, gchar *name);
+ZStream *z_stream_fd_new(gint fd, const gchar *name);
 
 #ifdef __cplusplus
 }
