@@ -19,6 +19,7 @@ extern "C" {
 #endif
 
 #define ZST_CTRL_SSL_SET_SESSION     (0x01) | ZST_CTRL_SSL_OFS
+#define ZST_CTRL_SSL_ADD_HANDSHAKE   (0x02) | ZST_CTRL_SSL_OFS
 
 ZStream * z_stream_ssl_new(ZStream *stream, ZSSLSession *ssl);
 
@@ -28,6 +29,23 @@ z_stream_ssl_set_session(ZStream *self, ZSSLSession *ssl)
   z_stream_ctrl(self, ZST_CTRL_SSL_SET_SESSION, ssl, sizeof(&ssl));
 }
 
+typedef struct
+{
+  gpointer handshake;
+  GDestroyNotify destroy_function;
+} ZStreamSslHandshakeData;
+
+static inline void
+z_stream_ssl_add_handshake(ZStream *self, gpointer handshake, GDestroyNotify destroy)
+{
+  ZStreamSslHandshakeData data;
+
+  data.handshake = handshake;
+  data.destroy_function = destroy;
+
+  z_stream_ctrl(self, ZST_CTRL_SSL_ADD_HANDSHAKE, &data, sizeof(data));
+}
+
 #ifdef __cplusplus
 }
 #endif
