@@ -3,6 +3,14 @@
 
 #include <zorp/stream.h>
 
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 ZStream *z_stream_tee_new(ZStream *child, ZStream *fork, GIOCondition tee_direction);
 
+#ifdef __cplusplus
+}
+#endif
+
 #endif
